@@ -32,22 +32,18 @@ class accuinsight(Common):
     def __init__(self):
         super().__init__()
 
-    def get_data_info(self):
+    def get_file(self, storage_json_file_name=None):
         global save_path, StorageInfo, target_name
-        save_path = self.save_path
-        StorageInfo = self.StorageInfo
-        target_name = self.target_name
+        save_path, StorageInfo, target_name = super().get_file(storage_json_file_name)
+
+    def set_features(self, feature_names):
+        global feature_name
+        feature_name = super().set_features(feature_names)
 
     class add_experiment(object):
         def __init__(self, model_name, *args, model_monitor=False):
-            accuinsight.get_data_info(accuinsight())
-
-            if model_monitor:
-                self.shap_on = True
-                logging.info('Using add_experiment(model_monitor=True)')
-            else:
-                self.shap_on = False
-                logging.info('Using add_experiment(model_monitor=False)')
+            self.shap_on = model_monitor
+            logging.info('Using add_experiment(model_monitor={})'.format(model_monitor))
             
             self.model_name = model_name
         
@@ -157,10 +153,14 @@ class accuinsight(Common):
             self.run_id = self.summary_info[LOGGING_RUN_ID]
             
             if self.shap_on:
-                try:
-                    self.feature_name = get.feature_name(save_path, StorageInfo, target_name)
-                except:
-                    self.feature_name = None
+                if not feature_name:
+                    try:
+                        self.feature_name = get.feature_name(save_path, StorageInfo, target_name)
+                    except:
+                        self.feature_name = None
+                else:
+                    self.feature_name = feature_name
+
                 self.run_id = self.fitted_model + '-' + self.run_id
                 
                 # when user uses lightGBM fitted by lightGBM datasets, convert data type to lightGBM dataset.
@@ -233,7 +233,6 @@ class accuinsight(Common):
         def log_params(self, param = None):
             # sklearn/xgboost/lightgbm
             if param:
-                
                 if param in self.model_param_keys:
                     return self.selected_params.append(param)
 
