@@ -92,6 +92,8 @@ class Common(object):
             self.storage_info_from_set['target'] = target
 
             self.save_path = file_path
+            self.StorageInfo = self.storage_info_from_set
+            self.target_name = target
 
         if save_json:
             if save_path is None:
@@ -203,6 +205,8 @@ class Common(object):
         else:
             self.save_path = self.StorageInfo['filePath']
 
+        return self.save_path, self.StorageInfo, self.target_name
+
     @staticmethod
     def _send_message(metric=None, current_value=None, message=None, thresholds=None, token=None, channel_id=None):
         logger = logging.getLogger(__name__)
@@ -249,4 +253,6 @@ class Common(object):
             try:
                 self.feature_name = list(feature_names)
             except AttributeError:
-                raise ValueError('입력값으로 list 또는 pandas.core.indexes.base.Index를 사용하시기 바랍니다.')
\ No newline at end of file
+                raise ValueError('입력값으로 list 또는 pandas.core.indexes.base.Index를 사용하시기 바랍니다.')
+
+        return feature_names
\ No newline at end of file
