@@ -104,8 +104,12 @@ class accuinsight(Common):
 
                 global start
                 start = get_time.now()
-                self.run_id = func.get_run_id()
-                self.model_type = get.model_type(self.model)
+                opt = self.model.optimizer.get_config()
+                opt_key = list(opt.keys())[1:]
+                opt_result = {k: np.float64(opt[k]) for k in opt_key}
+
+                # self.run_id = func.get_run_id()
+                # self.model_type = get.model_type(self.model)
 
                 self.model_summary['data_version'] = endpoint
                 self.model_summary['model_description'] = description
@@ -117,8 +121,8 @@ class accuinsight(Common):
                     self.model_summary['loss_function'] = self.model.loss.get_config()['name']
                 else:
                     self.model_summary['loss_function'] = self.model.loss
-
-                self.model_summary['optimizer_info'] = {type(self.model.optimizer).__name__: self.model.optimizer.get_config()}
+                self.model_summary['optimizer_info'] = {opt['name']: opt_result}
+                # self.model_summary['optimizer_info'] = {type(self.model.optimizer).__name__: self.model.optimizer.get_config()}
 
                 '''[get best model] on_train_begin '''
                 self.best_weights = self.model.get_weights()
@@ -127,7 +131,7 @@ class accuinsight(Common):
 
                 set_prefix_path(self.dict_path[LcConst.RUN_PREFIX_PATH])
 
-                set_run_name(self.model_type, self.run_id)
+                set_run_name(self.model_summary['model_type'], self.model_summary['run_id'])
                 set_python_dependencies(py_depenpency=dependencies)
 
             '''[get best model] on_epoch_end '''
@@ -243,9 +247,13 @@ class accuinsight(Common):
                     delete_files_except_best(run_id=self.model_summary['run_id'], epochs=str(self.last_epochs),
                     path=self.dict_path)
 
-                path_for_setting_model_json = self.dict_path['save_model_dir'] + get_best_model_path(run_id=self.model_summary['run_id'], path=self.dict_path)['json']
+                path_for_setting_model_json = self.dict_path['save_model_dir'] + \
+                                              get_best_model_path(run_id=self.model_summary['run_id'],
+                                                                  path=self.dict_path)['json']
+                path_for_setting_model_h5 = self.dict_path['save_model_dir'] + \
+                                            get_best_model_path(run_id=self.model_summary['run_id'],
+                                                                path=self.dict_path)['h5']
                 set_best_model_json_path(path_for_setting_model_json)
-                path_for_setting_model_h5 = self.dict_path['save_model_dir'] + get_best_model_path(run_id=self.model_summary['run_id'], path=self.dict_path)['h5']
                 set_best_model_h5_path(path_for_setting_model_h5)
 
                 start_ts = int(start.timestamp())
