@@ -33,6 +33,9 @@ class accuinsight(Common):
     def __init__(self):
         super().__init__()
 
+    def get_file(self, storage_json_file_name=None):
+        super().get_file(storage_json_file_name)
+
     def autolog(self, tag=None, best_weights=False, model_monitor=False):
         global description, endpoint, var_model_file_path, message, thresholds, token, channel_id, best_weights_on, run_id, shap_on, feature_name
         description = tag
@@ -46,6 +49,7 @@ class accuinsight(Common):
             best_weights_on = True
         else:
             best_weights_on = False
+
         if model_monitor:
             shap_on = True
             if self.feature_name is None:
@@ -91,23 +95,18 @@ class accuinsight(Common):
                 self.best_epochs = 0
                 self.epochs_since_last_save = 0
                 self.mode = mode
+                self.model_summary = OrderedDict()
 
             def on_train_begin(self, logs={}):
-                if best_weights_on and shap_on:
-                    logging.info('Using autolog(best_weights=True, model_monitor=True)')
-                elif best_weights_on == True and shap_on == False:
-                    logging.info('Using autolog(best_weights=True, model_monitor=False)')
-                elif best_weights_on == False and shap_on == True:
-                    logging.info('Using autolog(best_weights=False, model_monitor=True)')
-                else:
-                    logging.info('Using autolog(best_weights=False, model_monitor=False)')
+                logging.info('Using autolog(best_weights={}, model_monitor={}'
+                             .format(str(best_weights_on), str(shap_on)))
                 
                 global start
                 start = get_time.now()
                 opt = self.model.optimizer.get_config()
                 opt_key = list(opt.keys())[1:]
                 opt_result = {k: np.float64(opt[k]) for k in opt_key}
-                self.model_summary = OrderedDict()
+
                 self.model_summary['data_version'] = endpoint
                 self.model_summary['model_description'] = description
                 self.model_summary['logging_time'] = get_time.logging_time()
@@ -263,7 +262,6 @@ class accuinsight(Common):
                 self.y_val = y_validation
 
             def on_train_end(self, logs={}):
-
                 self.dict_path = path.get_file_path(self.model, usedFramework='tensorflow')
                 # path for visual.json
                 path_for_setting_visual_json = self.dict_path['visual_json']
@@ -287,10 +285,10 @@ class accuinsight(Common):
                         json.dump(visual_regression_json, save_file, indent="\t")
 
         class shapCallbacks(tensorflow.keras.callbacks.Callback):
-            def __init__(self, trainX, feature_name, run_id, trigger = shap_on):
+            def __init__(self, trainX, feature_name, run_id, trigger=shap_on):
                 super(shapCallbacks, self).__init__()
                 self.trainX = trainX
-                self.trigger = shap_on
+                self.trigger = trigger
                 self.run_id = run_id
                 self.feature_name_in_shap = feature_name
 
@@ -328,7 +326,7 @@ class accuinsight(Common):
             if 'x':
                 x_train = x
             if shap_on:
-                get_shap = shapCallbacks(x_train, feature_name, run_id, trigger = shap_on)
+                get_shap = shapCallbacks(x_train, feature_name, run_id, trigger=shap_on)
             else:
                 pass
             
@@ -354,22 +352,15 @@ class accuinsight(Common):
 
             if 'callbacks' in kwargs:
                 kwargs['callbacks'] += [csv_logger]
-                kwargs['callbacks'] += [get_visual]
-                if shap_on:
-                    kwargs['callbacks'] += [get_shap]
-                else:
-                    pass
-                kwargs['callbacks'] += [TrainHistoryCallbacks()]
-                
-
             else:
                 kwargs['callbacks'] = [csv_logger]
-                kwargs['callbacks'] += [get_visual]
-                if shap_on:
-                    kwargs['callbacks'] += [get_shap]
-                else:
-                    pass
-                kwargs['callbacks'] += [TrainHistoryCallbacks()]
+
+            kwargs['callbacks'] += [get_visual]
+            if shap_on:
+                kwargs['callbacks'] += [get_shap]
+            else:
+                pass
+            kwargs['callbacks'] += [TrainHistoryCallbacks()]
 
             return original(self, x, y, **kwargs)
 
